# Generated by Django 2.1.14 on 2020-05-11 11:24

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0063_accountphysicallocation'),
    ]

    operations = [
        migrations.AddField(
            model_name='ticket',
            name='first_response_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='first_response_due_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='resolution_plan_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='resolution_plan_due_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='resolved_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
        migrations.AddField(
            model_name='ticket',
            name='resolved_due_date_time',
            field=models.DateTimeField(blank=True, null=True),
        ),
    ]
