# Generated by Django 2.1.11 on 2019-10-21 10:28

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0016_auto_20191021_0958'),
    ]

    operations = [
        migrations.AlterModelManagers(
            name='displaycolor',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='issuetype',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='projectstatus',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='projecttype',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='queue',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='source',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='subissuetype',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketpriority',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='ticketstatus',
            managers=[
            ],
        ),
        migrations.AlterModelManagers(
            name='tickettype',
            managers=[
            ],
        ),
    ]
