# Generated by Django 2.1.11 on 2019-09-20 16:44

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0007_auto_20190917_1009'),
        ('djautotask', '0006_merge_20190920_1450'),
    ]

    operations = [
    ]
