# Generated by Django 2.1.11 on 2019-10-31 16:20

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0021_merge_20191031_0858'),
        ('djautotask', '0021_merge_20191031_1259'),
    ]

    operations = [
    ]
