# Generated by Django 2.1.14 on 2020-02-04 15:46

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0040_merge_20200131_1627'),
        ('djautotask', '0040_auto_20200204_1538'),
    ]

    operations = [
    ]
