# Generated by Django 3.1.2 on 2020-10-09 10:01

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0079_auto_20201003_1125'),
    ]

    operations = [
        migrations.CreateModel(
            name='AccountPhysicalLocationTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_accountphysicallocation',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.accountphysicallocation',),
        ),
        migrations.CreateModel(
            name='AccountTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_account',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.account',),
        ),
        migrations.CreateModel(
            name='AccountTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_accounttype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.accounttype',),
        ),
        migrations.CreateModel(
            name='AllocationCodeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_allocationcode',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.allocationcode',),
        ),
        migrations.CreateModel(
            name='ContractTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_contract',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.contract',),
        ),
        migrations.CreateModel(
            name='DepartmentTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_department',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.department',),
        ),
        migrations.CreateModel(
            name='DisplayColorTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_displaycolor',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.displaycolor',),
        ),
        migrations.CreateModel(
            name='IssueTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_issuetype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.issuetype',),
        ),
        migrations.CreateModel(
            name='LicenseTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_licensetype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.licensetype',),
        ),
        migrations.CreateModel(
            name='NoteTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_notetype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.notetype',),
        ),
        migrations.CreateModel(
            name='PhaseTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_phase',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.phase',),
        ),
        migrations.CreateModel(
            name='PriorityTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_priority',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.priority',),
        ),
        migrations.CreateModel(
            name='ProjectStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_projectstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.projectstatus',),
        ),
        migrations.CreateModel(
            name='ProjectTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_project',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.project',),
        ),
        migrations.CreateModel(
            name='ProjectTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_projecttype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.projecttype',),
        ),
        migrations.CreateModel(
            name='QueueTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_queue',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.queue',),
        ),
        migrations.CreateModel(
            name='ResourceRoleDepartmentTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_resourceroledepartment',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.resourceroledepartment',),
        ),
        migrations.CreateModel(
            name='ResourceServiceDeskRoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_resourceservicedeskrole',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.resourceservicedeskrole',),
        ),
        migrations.CreateModel(
            name='ResourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_resource',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.resource',),
        ),
        migrations.CreateModel(
            name='RoleTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_role',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.role',),
        ),
        migrations.CreateModel(
            name='ServiceCallStatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecallstatus',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecallstatus',),
        ),
        migrations.CreateModel(
            name='ServiceCallTaskResourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecalltaskresource',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecalltaskresource',),
        ),
        migrations.CreateModel(
            name='ServiceCallTaskTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecalltask',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecalltask',),
        ),
        migrations.CreateModel(
            name='ServiceCallTicketResourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecallticketresource',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecallticketresource',),
        ),
        migrations.CreateModel(
            name='ServiceCallTicketTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecallticket',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecallticket',),
        ),
        migrations.CreateModel(
            name='ServiceCallTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_servicecall',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.servicecall',),
        ),
        migrations.CreateModel(
            name='SourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_source',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.source',),
        ),
        migrations.CreateModel(
            name='StatusTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_status',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.status',),
        ),
        migrations.CreateModel(
            name='SubIssueTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_subissuetype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.subissuetype',),
        ),
        migrations.CreateModel(
            name='TaskNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_tasknote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.tasknote',),
        ),
        migrations.CreateModel(
            name='TaskPredecessorTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_taskpredecessor',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.taskpredecessor',),
        ),
        migrations.CreateModel(
            name='TaskSecondaryResourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_tasksecondaryresource',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.tasksecondaryresource',),
        ),
        migrations.CreateModel(
            name='TaskTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_task',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.task',),
        ),
        migrations.CreateModel(
            name='TaskTypeLinkTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_tasktypelink',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.tasktypelink',),
        ),
        migrations.CreateModel(
            name='TicketCategoryTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_ticketcategory',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.ticketcategory',),
        ),
        migrations.CreateModel(
            name='TicketNoteTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_ticketnote',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.ticketnote',),
        ),
        migrations.CreateModel(
            name='TicketSecondaryResourceTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_ticketsecondaryresource',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.ticketsecondaryresource',),
        ),
        migrations.CreateModel(
            name='TicketTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_ticket',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.ticket',),
        ),
        migrations.CreateModel(
            name='TicketTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_tickettype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.tickettype',),
        ),
        migrations.CreateModel(
            name='TimeEntryTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_timeentry',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.timeentry',),
        ),
        migrations.CreateModel(
            name='UseTypeTracker',
            fields=[
            ],
            options={
                'db_table': 'djautotask_usetype',
                'proxy': True,
                'indexes': [],
                'constraints': [],
            },
            bases=('djautotask.usetype',),
        ),
    ]
