# Generated by Django 2.1.11 on 2019-09-23 11:55

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0008_auto_20190917_1454'),
        ('djautotask', '0009_auto_20190920_1648'),
    ]

    operations = [
    ]
