# Generated by Django 2.1.11 on 2020-01-27 11:57

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0035_timeentry'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='displaycolor',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='issuetype',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='licensetype',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='priority',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='projectstatus',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='projecttype',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='queue',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='source',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='status',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='subissuetype',
            name='parent_value',
        ),
        migrations.RemoveField(
            model_name='tickettype',
            name='parent_value',
        ),
    ]
