# Generated by Django 4.0.7 on 2022-10-11 13:20

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0106_ticketnote_created_by_contact'),
    ]

    operations = [
        migrations.AddField(
            model_name='contact',
            name='extension',
            field=models.CharField(blank=True, max_length=10, null=True),
        ),
    ]
