# Generated by Django 2.1.14 on 2020-05-21 16:15

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0067_auto_20200519_1100'),
        ('djautotask', '0067_merge_20200514_1713'),
    ]

    operations = [
    ]
