# Generated by Django 2.1.14 on 2019-11-25 11:03

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('djautotask', '0026_auto_20191125_0952'),
    ]

    operations = [
        migrations.RenameField(
            model_name='task',
            old_name='priority_label',
            new_name='priority',
        ),
    ]
